@@ -138,8 +138,7 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
   switch (prop)
     {
     case GSASL_SAML20_IDP_IDENTIFIER:
-      gsasl_property_set (sctx, prop, "https://saml.example.org/");
-      rc = GSASL_OK;
+      rc = gsasl_property_set (sctx, prop, "https://saml.example.org/");
       break;
 
     case GSASL_SAML20_AUTHENTICATE_IN_BROWSER:
