@@ -1,5 +1,5 @@
 /* server.c --- SASL CRAM-MD5 server side functions.
- * Copyright (C) 2002-2020 Simon Josefsson
+ * Copyright (C) 2002-2021 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -94,9 +94,10 @@ _gsasl_cram_md5_server_step (Gsasl_session * sctx,
 
   memcpy (username, input, input_len - MD5LEN * 2 - 1);
 
-  gsasl_property_set (sctx, GSASL_AUTHID, username);
-
+  res = gsasl_property_set (sctx, GSASL_AUTHID, username);
   free (username);
+  if (res != GSASL_OK)
+    return res;
 
   password = gsasl_property_get (sctx, GSASL_PASSWORD);
   if (!password)
