@@ -85,15 +85,19 @@ _gsasl_saml20_server_step (Gsasl_session * sctx,
 
 	if (authzid)
 	  {
-	    gsasl_property_set (sctx, GSASL_AUTHZID, authzid);
+	    res = gsasl_property_set (sctx, GSASL_AUTHZID, authzid);
 	    free (authzid);
+	    if (res != GSASL_OK)
+	      return res;
 	  }
 
 	input += headerlen;
 	input_len -= headerlen;
 
-	gsasl_property_set_raw (sctx, GSASL_SAML20_IDP_IDENTIFIER,
-				input, input_len);
+	res = gsasl_property_set_raw (sctx, GSASL_SAML20_IDP_IDENTIFIER,
+				      input, input_len);
+	if (res != GSASL_OK)
+	  return res;
 
 	p = gsasl_property_get (sctx, GSASL_SAML20_REDIRECT_URL);
 	if (!p || !*p)
