@@ -45,6 +45,8 @@
  *
  * This is used internally by the library header file and should never
  * be used or modified by the application.
+ *
+ * https://www.gnu.org/software/gnulib/manual/html_node/Exported-Symbols-of-Shared-Libraries.html
  */
 #ifndef GSASL_API
 #if defined GSASL_BUILDING && defined HAVE_VISIBILITY && HAVE_VISIBILITY
@@ -197,29 +199,6 @@ extern "C"
     GSASL_QOP_AUTH_CONF = 4
   } Gsasl_qop;
 
-  /**
-   * Gsasl_cipher:
-   * @GSASL_CIPHER_DES: Cipher DES.
-   * @GSASL_CIPHER_3DES: Cipher 3DES.
-   * @GSASL_CIPHER_RC4: Cipher RC4.
-   * @GSASL_CIPHER_RC4_40: Cipher RC4 with 40-bit keys.
-   * @GSASL_CIPHER_RC4_56: Cipher RC4 with 56-bit keys.
-   * @GSASL_CIPHER_AES: Cipher AES.
-   *
-   * Encryption types (DIGEST-MD5) for confidentiality services of
-   * application data.  We recommend that you use TLS instead as it is
-   * generally more secure and have better chance of working.
-   */
-  typedef enum
-  {
-    GSASL_CIPHER_DES = 1,
-    GSASL_CIPHER_3DES = 2,
-    GSASL_CIPHER_RC4 = 4,
-    GSASL_CIPHER_RC4_40 = 8,
-    GSASL_CIPHER_RC4_56 = 16,
-    GSASL_CIPHER_AES = 32
-  } Gsasl_cipher;
-
   /**
    * Gsasl_saslprep_flags:
    * @GSASL_ALLOW_UNASSIGNED: Allow unassigned code points.
