@@ -139,6 +139,29 @@ map (Gsasl_session * sctx, Gsasl_property prop)
   return p;
 }
 
+/**
+ * gsasl_property_free:
+ * @sctx: session handle.
+ * @prop: enumerated value of %Gsasl_property type to clear
+ *
+ * Deallocate associated data with property @prop in session handle.
+ * After this call, gsasl_property_fast(@sctx, @prop) will always
+ * return NULL.
+ *
+ * Since: 2.0.0
+ **/
+void
+gsasl_property_free (Gsasl_session * sctx, Gsasl_property prop)
+{
+  char **p = map (sctx, prop);
+
+  if (p)
+    {
+      free (*p);
+      *p = NULL;
+    }
+}
+
 /**
  * gsasl_property_set:
  * @sctx: session handle.
@@ -152,13 +175,16 @@ map (Gsasl_session * sctx, Gsasl_property prop)
  * You can immediately deallocate @data after calling this function,
  * without affecting the data stored in the session handle.
  *
+ * Return value: %GSASL_OK iff successful, otherwise
+ * %GSASL_MALLOC_ERROR.
+ *
  * Since: 0.2.0
  **/
-void
+int
 gsasl_property_set (Gsasl_session * sctx, Gsasl_property prop,
 		    const char *data)
 {
-  gsasl_property_set_raw (sctx, prop, data, data ? strlen (data) : 0);
+  return gsasl_property_set_raw (sctx, prop, data, data ? strlen (data) : 0);
 }
 
 /**
@@ -178,9 +204,12 @@ gsasl_property_set (Gsasl_session * sctx, Gsasl_property prop,
  * Except for the length indicator, this function is identical to
  * gsasl_property_set.
  *
+ * Return value: %GSASL_OK iff successful, otherwise
+ * %GSASL_MALLOC_ERROR.
+ *
  * Since: 0.2.0
  **/
-void
+int
 gsasl_property_set_raw (Gsasl_session * sctx, Gsasl_property prop,
 			const char *data, size_t len)
 {
@@ -192,15 +221,17 @@ gsasl_property_set_raw (Gsasl_session * sctx, Gsasl_property prop,
       if (data)
 	{
 	  *p = malloc (len + 1);
-	  if (*p)
-	    {
-	      memcpy (*p, data, len);
-	      (*p)[len] = '\0';
-	    }
+	  if (!*p)
+	    return GSASL_MALLOC_ERROR;
+
+	  memcpy (*p, data, len);
+	  (*p)[len] = '\0';
 	}
       else
 	*p = NULL;
     }
+
+  return GSASL_OK;
 }
 
 /**
@@ -248,13 +279,6 @@ gsasl_property_fast (Gsasl_session * sctx, Gsasl_property prop)
  * This function will invoke the application callback, using
  * gsasl_callback(), when a property value is not known.
  *
- * If no value is known, and no callback is specified or if the
- * callback fail to return data, and if any obsolete callback
- * functions has been set by the application, this function will try
- * to call these obsolete callbacks, and store the returned data as
- * the corresponding property.  This behaviour of this function will
- * be removed when the obsolete callback interfaces are removed.
- *
  * Return value: Return data for property, or NULL if no value known.
  *
  * Since: 0.2.0
@@ -270,10 +294,5 @@ gsasl_property_get (Gsasl_session * sctx, Gsasl_property prop)
       p = gsasl_property_fast (sctx, prop);
     }
 
-#ifndef GSASL_NO_OBSOLETE
-  if (!p)
-    p = _gsasl_obsolete_property_map (sctx, prop);
-#endif
-
   return p;
 }
