@@ -70,8 +70,8 @@ gsasl_finish (Gsasl_session * sctx)
   free (sctx->saml20_redirect_url);
   free (sctx->openid20_redirect_url);
   free (sctx->openid20_outcome_data);
-  /* If you add anything here, remember to change change
-     gsasl_finish() in xfinish.c and Gsasl_session in internal.h.  */
+  /* If you add anything here, remember to change change map() in
+     property.c and Gsasl_session in internal.h.  */
 
   free (sctx);
 }
