@@ -45,13 +45,11 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
   switch (prop)
     {
     case GSASL_PASSWORD:
-      gsasl_property_set (sctx, GSASL_PASSWORD, PASSWORD);
-      rc = GSASL_OK;
+      rc = gsasl_property_set (sctx, GSASL_PASSWORD, PASSWORD);
       break;
 
     case GSASL_AUTHID:
-      gsasl_property_set (sctx, GSASL_AUTHID, USERNAME);
-      rc = GSASL_OK;
+      rc = gsasl_property_set (sctx, GSASL_AUTHID, USERNAME);
       break;
 
     default:
