@@ -48,18 +48,15 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
   switch (prop)
     {
     case GSASL_AUTHZID:
-      gsasl_property_set (sctx, GSASL_AUTHZID, USERNAME[i]);
-      rc = GSASL_OK;
+      rc = gsasl_property_set (sctx, GSASL_AUTHZID, USERNAME[i]);
       break;
 
     case GSASL_SERVICE:
-      gsasl_property_set (sctx, prop, SERVICE);
-      rc = GSASL_OK;
+      rc = gsasl_property_set (sctx, prop, SERVICE);
       break;
 
     case GSASL_HOSTNAME:
-      gsasl_property_set (sctx, prop, HOST);
-      rc = GSASL_OK;
+      rc = gsasl_property_set (sctx, prop, HOST);
       break;
 
     case GSASL_VALIDATE_GSSAPI:
@@ -95,7 +92,7 @@ doit (void)
   char *s1 = NULL, *s2 = NULL;
   int rc, res1, res2;
 
-  if (getenv ("GNUGSS") && strcmp (getenv ("GNUGSS"), "no") == 0)
+  if (getenv ("GNUGSS") == NULL || strcmp (getenv ("GNUGSS"), "yes") != 0)
     {
       fail ("Not using GNU GSS, skipping self-test.\n");
       exit (77);
